@@ -1,29 +1,36 @@
 #ifndef DIGITALCLOCKWDG_H
 #define DIGITALCLOCKWDG_H
 
-#include <QLCDNumber>
+//#include <QWidget>
+#include <QGraphicsView>
+#include <QGraphicsScene>
+#include <QPushButton>
+//class QGraphicsView;
+//class QGraphicsScene;
 
 //class SettingsDialog;
 
-class DigitalClockWdg : public QWidget
+class DigitalClockWdg : public QGraphicsView
 {
     Q_OBJECT
 
 signals:
     void updateClock(QString);
+    void rotateClock();
 
 public slots:
     void showSettingsDialog();
     void homeScreenChanged(bool isOnCurrentHomescreen);
+    void orientationChanged(QString aMessage);
 
 public:
-    DigitalClockWdg(QWidget *parent = 0);
+    DigitalClockWdg(QGraphicsScene *scene);
     void setId(QString &aAppletId);
 
 protected:
     void mouseReleaseEvent ( QMouseEvent * e );
     void mousePressEvent ( QMouseEvent * e );
-    void paintEvent(QPaintEvent *event);
+//    void paintEvent(QPaintEvent *event);
 
 private slots:
     void showTime();
@@ -33,6 +40,8 @@ private:
     void initClock();
     void showClock();
     QTime calcTime();
+    void enableRotationMonitor(bool aRotatable);
+    int drawCityName();
 
 private:
     QWidget * clk1;
@@ -51,6 +60,22 @@ private:
     int m_tzOffset;
     QString m_aplletId;
     float m_transparency;
+
+    QGraphicsScene* m_scene;
+    QGraphicsProxyWidget *m_gProxy;
+    QGraphicsLineItem *m_gLine;
+    QGraphicsTextItem *m_gCity;
+
+    int m_sc_x;
+    int m_sc_y;
+
+    bool m_rotate;
+    bool m_openclock;
+    bool m_showCity;
+    QString m_cityName;
+    int m_citySize;
+    int m_hCity;
+    int m_wCity;
 };
 
 #endif
