@@ -25,15 +25,7 @@
     <message>
         <source>Digits Color</source>
         <translation type="unfinished">Цвет Цифр</translation>
-    </message>
-    <message>
-        <source>Seconds</source>
-        <translation type="unfinished">cекунды</translation>
-    </message>
-    <message>
-        <source>Format</source>
-        <translation type="unfinished">Формат</translation>
-    </message>
+    </message>	
     <message>
         <source>24H</source>
         <translation type="unfinished">24 часа</translation>
@@ -45,39 +37,64 @@
     <message>
         <source>Military</source>
         <translation type="unfinished">военный</translation>
-    </message>
+    </message>	
     <message>
         <source>About</source>
         <translation type="unfinished">О программе</translation>
     </message>
     <message>
-        <source>About Qt</source>
+        <location filename="settingsdialog.ui" line="268"/>		
         <translation type="unfinished">Qt</translation>
-    </message>
+    </message>	
     <message>
+        <location filename="settingsdialog.ui" line="88"/>	
         <source>Font</source>
         <translation type="unfinished">Шрифт</translation>
-    </message>
+    </message>	
     <message>
+        <location filename="settingsdialog.ui" line="98"/>	
         <source>Default (LCD)</source>
         <translation type="unfinished">Исходный (LCD)</translation>
-    </message>
-    <message>
-        <source>B</source>
-        <translation type="unfinished">Ж</translation>
-    </message>
-    <message>
-        <source>I</source>
-        <translation type="unfinished">К</translation>
-    </message>
+    </message>	
     <message>
         <source>About DigiClock</source>
         <translation type="unfinished">О программе DigiClock</translation>
-    </message>
+    </message>	
     <message>
+        <location filename="settingsdialog.ui" line="118"/>	
+        <source>B</source>
+        <translation type="unfinished">Ж</translation>
+    </message>	
+    <message>
+        <location filename="settingsdialog.ui" line="136"/>	
+        <source>I</source>
+        <translation type="unfinished">К</translation>
+    </message>	
+    <message>
+        <location filename="settingsdialog.ui" line="155"/>	
         <source>12:48</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Display</source>
+        <translation type="unfinished">Отображение</translation>
+    </message>		
+    <message>
+        <source>Transparency</source>	
+        <translation type="unfinished">Прозрачность</translation>
+    </message>
+    <message>
+        <source>System</source>
+        <translation type="unfinished">Опции</translation>
+    </message>	
+    <message>
+        <source>Format</source>
+        <translation type="unfinished">Формат</translation>
+    </message>
+    <message>
+        <source>Seconds</source>
+        <translation type="unfinished">cекунды</translation>
+    </message>
     <message>
         <source>Blinking</source>
         <translation type="unfinished">мигание</translation>
@@ -87,8 +104,33 @@
         <translation type="unfinished">Часовой пояс</translation>
     </message>	
     <message>
-        <source>&lt;b&gt;DigiClock&lt;/b&gt; 0.3.0&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing digital time</source>
-        <translation type="unfinished">&lt;b&gt;DigiClock&lt;/b&gt; 0.3.0&lt;br&gt;Написано на &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Виджет, отображающий цифровое время на рабочем столе</translation>
-    </message>	
+        <source>Show City</source>
+        <translation type="unfinished">Городs</translation>
+    </message>
+    <message>
+        <source>Open Clock app on Click</source>
+        <translation type="unfinished">Открывать часы по клику</translation>
+    </message>
+    <message>
+        <source>Rotate on Accel</source>
+        <translation type="unfinished">Автоповорот</translation>
+    </message>
+    <message>
+        <source>DigiClock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Developed with</source>
+        <translation type="unfinished">Написано на</translation>
+    </message>
+    <message>
+        <source>Desktop widget, showing digital time</source>
+        <translation type="unfinished">Виджет, отображающий время в цифровом формате</translation>
+    </message>
+    <message>
+        <source>Send reports to:</source>
+        <translation type="unfinished">Письмо автору:</translation>
+    </message>
+
 </context>
 </TS>
