@@ -4,11 +4,16 @@
 #include <QFontDatabase>
 #include <QDateTime>
 
+#if defined(Q_WS_MAEMO_5)
+#include <cityinfo.h>
+#include <clockd/libtime.h>
+#endif
+
 #include "settingsdialog.h"
 #include "ui_settingsdialog.h"
 #include "dclocksettings.h"
 
-#define STR_VERSION "0.3.1"
+#define STR_VERSION "0.4.0"
 #define STR_CRLF "<br>"
 #define STR_QT_VERSION "<b>Qt 4.6.2</b>"
 #define STR_COPYRIGHT "Copyright (c) 2010 Avis"
@@ -24,7 +29,8 @@ SettingsDialog::SettingsDialog(QString &aAppletId, QWidget *parent) :
     ui->chbBold->setEnabled(false);
     ui->chbItalic->setEnabled(false);
     //m_defTZoffset = -50000;
-    fillCbTZ();
+//    fillCbTZ();
+    fillTZlist();
     loadSettings();
 }
 
@@ -33,7 +39,7 @@ SettingsDialog::~SettingsDialog()
     delete ui;
 }
 
-void SettingsDialog::fillCbTZ()
+/*void SettingsDialog::fillCbTZ()
 {
     ui->cbTZ->addItem("UTC-12",-43200);
     ui->cbTZ->addItem("UTC-11",-39600);
@@ -71,7 +77,7 @@ void SettingsDialog::fillCbTZ()
     ui->cbTZ->addItem("UTC+13",46800);
     ui->cbTZ->addItem("UTC+14",50400);
 }
-
+*/
 void SettingsDialog::buildFontList()
 {
     QFontDatabase database;
@@ -107,13 +113,26 @@ void SettingsDialog::dumpSettings() const
         dclocksettings::getInstance().setLcd(m_appletId,false);
     dclocksettings::getInstance().setFont(m_appletId,m_font);
     dclocksettings::getInstance().setBlinking(m_appletId,ui->chbBlink->isChecked());
-    int tzOffset = ui->cbTZ->itemData(ui->cbTZ->currentIndex(),Qt::UserRole).toInt();
+    int tzIndex = ui->cbTZ->currentIndex();
+    int tzOffset = ui->cbTZ->itemData(tzIndex,Qt::UserRole).toInt();
     int defOffest = calcOffset();
     if (tzOffset == defOffest)
         dclocksettings::getInstance().setTZoffset(m_appletId,-50000);
     else
         dclocksettings::getInstance().setTZoffset(m_appletId,tzOffset);
+    dclocksettings::getInstance().setTZindex(m_appletId,tzIndex);
+    QString tzCity = ui->cbTZ->currentText();
+    int strpos1 = tzCity.indexOf(",");
+    int strpos2 = tzCity.indexOf(",",strpos1+1);
+    tzCity = tzCity.mid(strpos1+2,strpos2-strpos1-2);
+    if (tzCity.isEmpty())
+        tzCity = "unknown";
+    dclocksettings::getInstance().setTZcity(m_appletId,tzCity);
     dclocksettings::getInstance().setTransparency(m_appletId,ui->hzSliderTransparency->value());
+    dclocksettings::getInstance().setRotateEnabled(m_appletId,ui->chbRotate->isChecked());
+    dclocksettings::getInstance().setOpenClockEnabled(m_appletId,ui->chbOpenClock->isChecked());
+    dclocksettings::getInstance().setShowCityEnabled(m_appletId,ui->chbShowCity->isChecked());
+    dclocksettings::getInstance().setCitySize(m_appletId,ui->spinCitySize->value());
 }
 
 int SettingsDialog::calcOffset() const
@@ -131,29 +150,39 @@ void SettingsDialog::loadSettings()
     QPalette qp = ui->labelColor->palette();
     qp.setColor(QPalette::WindowText,dColor);
     ui->labelColor->setPalette(qp);
-    ui->checkBox->setChecked(dclocksettings::getInstance().getShowSeconds(m_appletId));
+    ui->checkBox->setChecked(dclocksettings::getInstance().isShowSeconds(m_appletId));
     ui->cbTimeFormat->setCurrentIndex(dclocksettings::getInstance().getTimeFormat(m_appletId));
     QSize wSize = dclocksettings::getInstance().getSize(m_appletId);
     ui->spinWidth->setValue(wSize.width());
     ui->spinHeight->setValue(wSize.height());
-    ui->chbBlink->setChecked(dclocksettings::getInstance().getBlinking(m_appletId));
+    ui->chbBlink->setChecked(dclocksettings::getInstance().isBlinking(m_appletId));
     ui->hzSliderTransparency->setValue(dclocksettings::getInstance().getTransparency(m_appletId));
+    ui->chbRotate->setChecked(dclocksettings::getInstance().isRotateEnabled(m_appletId));
+    ui->chbOpenClock->setChecked(dclocksettings::getInstance().isOpenClockEnabled(m_appletId));
+    ui->chbShowCity->setChecked(dclocksettings::getInstance().isShowCityEnabled(m_appletId));
+    ui->spinCitySize->setValue(dclocksettings::getInstance().getCitySize(m_appletId));
 
-    int tzOffset = dclocksettings::getInstance().getTZoffset(m_appletId);
-    if (tzOffset == -50000)
+//    int tzOffset = dclocksettings::getInstance().getTZoffset(m_appletId);
+    int tzIndex = dclocksettings::getInstance().getTZindex(m_appletId);
+//    QString tzCity = dclocksettings::getInstance().getTZcity(m_appletId);
+    if (tzIndex > -1)
     {
+        ui->cbTZ->setCurrentIndex(tzIndex);
+    }
+//    if (tzOffset != -50000)
+  //  {
         // calc current time zone
 /*        QDateTime dt = QDateTime::currentDateTime();
         QDateTime udt = dt.toUTC();
         QTime tm = dt.time();
         QTime utm = udt.time();*/
-        tzOffset = calcOffset();
+//        tzOffset = calcOffset();
 //        m_defTZoffset = tzOffset; // save current TZ offset
-    }
-    int i = ui->cbTZ->findData(tzOffset, int(Qt::UserRole));
-    ui->cbTZ->setCurrentIndex(i);
+//    }
+//    int i = ui->cbTZ->findData(tzOffset, int(Qt::UserRole));
+//    ui->cbTZ->setCurrentIndex(i);
 
-    if (dclocksettings::getInstance().getLcd(m_appletId))
+    if (dclocksettings::getInstance().isLcd(m_appletId))
         ui->cbFont->setCurrentIndex(0);
     else
     {
@@ -205,6 +234,7 @@ void SettingsDialog::showQtAbout()
 
 void SettingsDialog::fontChanged(int aIndex)
 {
+    Q_UNUSED(aIndex);
     if (ui->cbFont->currentIndex() == 0)
     {
         ui->chbBold->setEnabled(false);
@@ -220,3 +250,46 @@ void SettingsDialog::fontChanged(int aIndex)
         ui->labelColor->setFont(m_font);
     }
 }
+
+void SettingsDialog::fillTZlist()
+{
+#if  defined(Q_WS_MAEMO_5)
+    int ret = 0;
+    char current_tz[32];
+    ret = time_get_timezone(&current_tz[0],32);
+
+    QString defTZ = QString::fromUtf8(current_tz);
+
+    ui->cbTZ->clear();
+    //    int k = 0; //
+    Cityinfo **cities = cityinfo_get_all();
+    for (int i = 0; cities && cities[i]; ++i) {
+
+        QString name = QString::fromUtf8(cityinfo_get_name(cities[i]));
+        QString country = QString::fromUtf8(cityinfo_get_country(cities[i]));
+        QString zone = ":" + QString::fromUtf8(cityinfo_get_zone(cities[i]));
+
+    //        if (zone == defTZ)
+    //          k = i;
+
+        QString timeoffset;
+        QString sign;
+        int offset = time_get_utc_offset(cityinfo_get_zone(cities[i]));
+        if (offset > 0)
+            sign = "";
+        else
+            sign = "+";
+        if((offset % 3600)==0)
+            timeoffset = QString("%2, %1, (UTC %3)").arg(name).arg(country).arg(sign+QString::number(-offset/3600));
+        else
+            timeoffset = QString("%2, %1, (UTC %3:%4)").arg(name).arg(country).arg(sign+QString::number(-offset/3600)).arg("30");
+        ui->cbTZ->addItem(timeoffset,-offset);
+        if (zone == defTZ)
+            defTZ = timeoffset;
+    }
+    cityinfo_free_all(cities);
+    ui->cbTZ->model()->sort(0);
+    int k = ui->cbTZ->findText(defTZ);
+    ui->cbTZ->setCurrentIndex(k);
+#endif
+}
