@@ -29,8 +29,9 @@ private slots:
 private:
     void loadSettings();
     void buildFontList();
-    void fillCbTZ();
+//    void fillCbTZ();
     int calcOffset() const;
+    void fillTZlist();
 
 private:
     QString m_appletId;
